# seremi

Read SER microscope image files and the associated EMI metadata files.

Install from [PyPI](https://pypi.org/project/seremi/): `pip install seremi`

[Docs](https://thenelsonlab.github.io/seremi/build/html/index.html)
